#!D:\bld\gdal-split_1648453471149\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.4.2','gdal2tiles.py'
__requires__ = 'GDAL==3.4.2'
__import__('pkg_resources').run_script('GDAL==3.4.2', 'gdal2tiles.py')
